@@ -13,14 +13,14 @@ class ControlReqDriver(BaseDriver):
 
     def __call__(self, *args, **kwargs):
         if self.req.command == jina_pb2.Request.ControlRequest.TERMINATE:
-            self.envelope.status = jina_pb2.Envelope.SUCCESS
+            self.envelope.status.code = jina_pb2.Status.SUCCESS
             raise RequestLoopEnd
         elif self.req.command == jina_pb2.Request.ControlRequest.STATUS:
-            self.envelope.status = jina_pb2.Envelope.READY
+            self.envelope.status.code = jina_pb2.Status.READY
             for k, v in vars(self.pea.args).items():
                 self.req.args[k] = str(v)
         elif self.req.command == jina_pb2.Request.ControlRequest.DRYRUN:
-            self.envelope.status = jina_pb2.Envelope.READY
+            self.envelope.status.code = jina_pb2.Status.READY
         else:
             raise UnknownControlCommand('don\'t know how to handle %s' % self.req)
 
@@ -28,8 +28,12 @@ class ControlReqDriver(BaseDriver):
 class LogInfoDriver(BaseDriver):
     """Log output the request info"""
 
+    def __init__(self, field: str = 'msg', *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.field = field
+
     def __call__(self, *args, **kwargs):
-        self.logger.info(self.req)
+        self.logger.info(getattr(self, self.field, 'msg'))
 
 
 class WaitDriver(BaseDriver):
@@ -46,6 +50,24 @@ class ForwardDriver(BaseDriver):
         pass
 
 
+class PublishDriver(ControlReqDriver):
+    """Publish the message to multiple pods
+
+    .. note::
+        used with PUB_BIND port
+    """
+
+    def __init__(self, num_part: int, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+        self.num_part = num_part
+
+    def __call__(self, *args, **kwargs):
+        if is_data_request(self.req):
+            self.envelope.num_part.append(self.num_part)
+        else:
+            super().__call__(*args, **kwargs)
+
+
 class RouteDriver(ControlReqDriver):
     """A simple load balancer forward message to the next available pea
 
