@@ -20,13 +20,15 @@ class VectorIndexDriver(BaseIndexDriver):
     """
 
     def __call__(self, *args, **kwargs):
-        embed_vecs, chunk_pts, no_chunk_docs, bad_chunk_ids = extract_chunks(self.req.docs, embedding=True)
+        embed_vecs, chunk_pts, no_chunk_docs, bad_chunk_ids = extract_chunks(self.docs, self.chunks,
+                                                                             self.req.filter_by,
+                                                                             embedding=True)
 
         if no_chunk_docs:
-            self.pea.logger.warning('these docs contain no chunk: %s' % no_chunk_docs)
+            self.pea.logger.warning(f'these docs contain no chunk: {no_chunk_docs}')
 
         if bad_chunk_ids:
-            self.pea.logger.warning('these bad chunks can not be added: %s' % bad_chunk_ids)
+            self.pea.logger.warning(f'these bad chunks can not be added: {bad_chunk_ids}')
 
         if chunk_pts:
             self.exec_fn(np.array([c.chunk_id for c in chunk_pts]), np.stack(embed_vecs))
@@ -57,28 +59,12 @@ class KVIndexDriver(BaseIndexDriver):
         self.level = level
 
     def __call__(self, *args, **kwargs):
-        from google.protobuf.json_format import MessageToJson
         if self.level == 'doc':
-            content = {f'd{d.doc_id}': MessageToJson(d) for d in self.req.docs}
+            content = self.docs
         elif self.level == 'chunk':
-            content = {f'c{c.chunk_id}': MessageToJson(c) for d in self.req.docs for c in d.chunks}
-        elif self.level == 'all':
-            content = {f'c{c.chunk_id}': MessageToJson(c) for d in self.req.docs for c in d.chunks}
-            content.update({f'd{d.doc_id}': MessageToJson(d) for d in self.req.docs})
+            content = (c for d in self.docs for c in self.chunks(d) if
+                       (not self.req.filter_by or c.field_name in self.req.filter_by))
         else:
             raise TypeError(f'level={self.level} is not supported, must choose from "chunk" or "doc" ')
         if content:
             self.exec_fn(content)
-
-
-class DocKVIndexDriver(KVIndexDriver):
-    """A shortcut of :class:`MergeTopKDriver` with ``level=chunk``"""
-
-    def __init__(self, level: str = 'doc', *args, **kwargs):
-        super().__init__(level, *args, **kwargs)
-
-
-class ChunkKVIndexDriver(KVIndexDriver):
-
-    def __init__(self, level: str = 'chunk', *args, **kwargs):
-        super().__init__(level, *args, **kwargs)
