@@ -42,16 +42,16 @@ class KVSearchDriver(BaseSearchDriver):
 
     def __call__(self, *args, **kwargs):
         if self.level == 'doc':
-            for d in self.req.docs:
+            for d in self.docs:
                 self._update_topk_docs(d)
         elif self.level == 'chunk':
-            for d in self.req.docs:
-                for c in d.chunks:
+            for d in self.docs:
+                for c in self.chunks(d):
                     self._update_topk_chunks(c)
         elif self.level == 'all':
-            for d in self.req.docs:
+            for d in self.docs:
                 self._update_topk_docs(d)
-                for c in d.chunks:
+                for c in self.chunks(d):
                     self._update_topk_chunks(c)
         else:
             raise TypeError(f'level={self.level} is not supported, must choose from "chunk" or "doc" ')
@@ -59,7 +59,7 @@ class KVSearchDriver(BaseSearchDriver):
     def _update_topk_docs(self, d):
         hit_sr = []  #: hited scored results, not some search may not ends with result. especially in shards
         for tk in d.topk_results:
-            r = self.exec_fn(f'd{tk.match_doc.doc_id}')
+            r = self.exec_fn(tk.match_doc.doc_id)
             if r:
                 sr = ScoredResult()
                 sr.score.CopyFrom(tk.score)
@@ -71,7 +71,7 @@ class KVSearchDriver(BaseSearchDriver):
     def _update_topk_chunks(self, c):
         hit_sr = []  #: hited scored results, not some search may not ends with result. especially in shards
         for tk in c.topk_results:
-            r = self.exec_fn(f'c{tk.match_chunk.chunk_id}')
+            r = self.exec_fn(tk.match_chunk.chunk_id)
             if r:
                 sr = ScoredResult()
                 sr.score.CopyFrom(tk.score)
@@ -101,13 +101,15 @@ class VectorSearchDriver(BaseSearchDriver):
     """
 
     def __call__(self, *args, **kwargs):
-        embed_vecs, chunk_pts, no_chunk_docs, bad_chunk_ids = extract_chunks(self.req.docs, embedding=True)
+        embed_vecs, chunk_pts, no_chunk_docs, bad_chunk_ids = extract_chunks(self.docs, self.chunks,
+                                                                             self.req.filter_by,
+                                                                             embedding=True)
 
         if no_chunk_docs:
-            self.logger.warning('these docs contain no chunk: %s' % no_chunk_docs)
+            self.logger.warning(f'these docs contain no chunk: {no_chunk_docs}')
 
         if bad_chunk_ids:
-            self.logger.warning('these bad chunks can not be added: %s' % bad_chunk_ids)
+            self.logger.warning(f'these bad chunks can not be added: {bad_chunk_ids}')
 
         idx, dist = self.exec_fn(embed_vecs, top_k=self.req.top_k)
         op_name = self.exec.__class__.__name__
