@@ -67,7 +67,7 @@ class BetterEnum(IntEnum, metaclass=EnumType):
         try:
             return cls[s.upper()]
         except KeyError:
-            raise ValueError('%s is not a valid enum for %s' % (s.upper(), cls))
+            raise ValueError(f'{s.upper()} is not a valid enum for {cls}')
 
     @classmethod
     def to_yaml(cls, representer, data):
@@ -211,3 +211,25 @@ class PeaRoleType(BetterEnum):
     HEAD = 1
     TAIL = 2
     SHARD = 3
+    SINGLETON = 4
+
+
+class ClientMode(BetterEnum):
+    """ The enum of Client mode
+
+    """
+    INDEX = 0
+    SEARCH = 1
+    TRAIN = 2
+
+
+class OnErrorSkip(BetterEnum):
+    """ The level of error handling
+
+    """
+
+    NONE = 0
+    EXECUTOR = 1
+    DRIVER = 2
+    HANDLE = 3
+    CALLBACK = 4
