@@ -3,26 +3,16 @@ __license__ = "Apache-2.0"
 
 import numpy as np
 
-from ..executors.crafters import BaseSegmenter, BaseDocCrafter
+from ..executors.crafters import BaseSegmenter
 from ..executors.encoders import BaseImageEncoder
 
 
-class MyDocCrafter(BaseDocCrafter):
-    """Simple DocCrafter used in :command:`jina hello-world`,
-    it reads ``raw_bytes`` into base64 png and stored in ``meta_info``"""
-
-    def craft(self, raw_bytes, *args, **kwargs):
-        doc = np.frombuffer(raw_bytes, dtype=np.uint8)
-        from .helper import write_png
-        return dict(meta_info=write_png(doc))
-
-
 class MySegmenter(BaseSegmenter):
     """Simple Segementer used in :command:`jina hello-world`,
     each doc contains only one chunk """
 
-    def craft(self, raw_bytes, doc_id, *args, **kwargs):
-        return [dict(blob=np.frombuffer(raw_bytes, dtype=np.uint8))]
+    def craft(self, blob, *args, **kwargs):
+        return [dict(blob=blob)]
 
 
 class MyEncoder(BaseImageEncoder):
