@@ -36,10 +36,12 @@ def start_sse_logger(server_config_path: str, flow_yaml: str = None):
     try:
         from flask import Flask, Response, jsonify
         from flask_cors import CORS
+        from gevent.pywsgi import WSGIServer
+        import gevent
     except ImportError:
         raise ImportError('Flask or its dependencies are not fully installed, '
                           'they are required for serving HTTP requests.'
-                          'Please use pip install "jina[flask]" to install it.')
+                          'Please use pip install "jina[http]" to install it.')
 
     try:
         with open(server_config_path) as fp:
@@ -48,11 +50,35 @@ def start_sse_logger(server_config_path: str, flow_yaml: str = None):
         default_logger.error(ex)
     JINA_GLOBAL.logserver.address = f'http://{_config["host"]}:{_config["port"]}'
 
-    JINA_GLOBAL.logserver.ready = JINA_GLOBAL.logserver.address + _config['endpoints']['ready']
-    JINA_GLOBAL.logserver.shutdown = JINA_GLOBAL.logserver.address + _config['endpoints']['shutdown']
+    JINA_GLOBAL.logserver.ready = JINA_GLOBAL.logserver.address + \
+        _config['endpoints']['ready']
+    JINA_GLOBAL.logserver.shutdown = JINA_GLOBAL.logserver.address + \
+        _config['endpoints']['shutdown']
 
     app = Flask(__name__)
     CORS(app)
+    server = WSGIServer((_config['host'], _config['port']), app, log=None)
+
+    def _log_stream():
+        while True:
+            try:
+                gevent.sleep(0)
+                message = __sse_queue__.get()
+                yield f'data: {message.msg}\n\n'
+            except EOFError:
+                yield 'LOG ENDS\n\n'
+                break
+
+    def _profile_stream():
+        while True:
+            try:
+                gevent.sleep(0)
+                message = __profile_queue__.get()
+                yield f'data: {message.msg}\n\n'
+            except EOFError:
+                yield 'PROFILE ENDS\n\n'
+                break
+
 
     @app.route(_config['endpoints']['log'])
     def get_log():
@@ -93,42 +119,14 @@ def start_sse_logger(server_config_path: str, flow_yaml: str = None):
 
     @app.route(_config['endpoints']['shutdown'])
     def shutdown():
-        from flask import request
-        if not 'werkzeug.server.shutdown' in request.environ:
-            raise RuntimeError('Not running the development server')
-        request.environ['werkzeug.server.shutdown']()
+        server.stop()
         return 'Server shutting down...'
 
     @app.route(_config['endpoints']['ready'])
     def is_ready():
         return Response(status=200)
 
-    os.environ['WERKZEUG_RUN_MAIN'] = 'true'
-    log = logging.getLogger('werkzeug')
-    log.disabled = True
-
     try:
-        app.logger.disabled = True
-        app.run(port=_config['port'], host=_config['host'])
+        server.serve_forever()
     except Exception as ex:
         default_logger.error(ex)
-
-
-def _log_stream():
-    while True:
-        try:
-            message = __sse_queue__.get()
-            yield 'data: {}\n\n'.format(message.msg)
-        except EOFError:
-            yield 'LOG ENDS\n\n'
-            break
-
-
-def _profile_stream():
-    while True:
-        try:
-            message = __profile_queue__.get()
-            yield 'data: {}\n\n'.format(message.msg)
-        except EOFError:
-            yield 'PROFILE ENDS\n\n'
-            break
