@@ -40,7 +40,7 @@ ac_table = {
                 '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--replica-id',
                 '--check-version', '--array-in-pb', '--compress-hwm', '--compress-lwm', '--num-part', '--role',
                 '--memory-hwm', '--runtime', '--max-idle-time', '--log-sse', '--log-remote', '--log-profile',
-                '--log-with-own-name', '--host', '--port-grpc', '--max-message-size', '--proxy', '--replicas',
+                '--log-with-own-name', '--host', '--port-expose', '--max-message-size', '--proxy', '--replicas',
                 '--polling', '--scheduling', '--reducing-yaml-path', '--shutdown-idle'],
         'flow': ['--help', '--yaml-path', '--logserver', '--logserver-config', '--optimize-level', '--output-type',
                  '--output-path'],
@@ -50,7 +50,7 @@ ac_table = {
                     '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--replica-id',
                     '--check-version', '--array-in-pb', '--compress-hwm', '--compress-lwm', '--num-part', '--role',
                     '--memory-hwm', '--runtime', '--max-idle-time', '--log-sse', '--log-remote', '--log-profile',
-                    '--log-with-own-name', '--host', '--port-grpc', '--max-message-size', '--proxy', '--prefetch',
+                    '--log-with-own-name', '--host', '--port-expose', '--max-message-size', '--proxy', '--prefetch',
                     '--prefetch-on-recv', '--allow-spawn', '--rest-api', '--to-datauri'],
         'ping': ['--help', '--timeout', '--retries', '--print-response'],
         'check': ['--help', '--summary-exec', '--summary-driver'], 'hub': ['--help', 'build', 'push', 'pull'],
@@ -60,9 +60,9 @@ ac_table = {
                 '--dump-interval', '--exit-no-dump', '--read-only', '--separated-workspace', '--replica-id',
                 '--check-version', '--array-in-pb', '--compress-hwm', '--compress-lwm', '--num-part', '--role',
                 '--memory-hwm', '--runtime', '--max-idle-time', '--log-sse', '--log-remote', '--log-profile',
-                '--log-with-own-name', '--host', '--port-grpc', '--max-message-size', '--proxy'],
+                '--log-with-own-name', '--host', '--port-expose', '--max-message-size', '--proxy'],
         'log': ['--help', '--groupby-regex', '--refresh-time'],
-        'client': ['--help', '--host', '--port-grpc', '--max-message-size', '--proxy', '--batch-size', '--mode',
+        'client': ['--help', '--host', '--port-expose', '--max-message-size', '--proxy', '--batch-size', '--mode',
                    '--top-k', '--mime-type', '--callback-on-body', '--first-request-id', '--first-doc-id',
                    '--random-doc-id', '--timeout-ready', '--filter-by'],
         'export-api': ['--help', '--yaml-path', '--json-path']}}
