@@ -6,23 +6,21 @@ import multiprocessing
 import os
 import threading
 import time
-from collections import defaultdict
+import traceback
 from queue import Empty
-from typing import Dict, List, Optional, Union
+from typing import Dict, Optional, Union
 
 import zmq
 
 from .zmq import send_ctrl_message, Zmqlet
 from .. import __ready_msg__, __stop_msg__
 from ..drivers.helper import routes2str, add_route
-from ..enums import PeaRoleType
-from ..excepts import NoExplicitMessage, ExecutorFailToLoad, MemoryOverHighWatermark, UnknownControlCommand, \
-    RequestLoopEnd, \
-    DriverNotInstalled, NoDriverForRequest
+from ..enums import PeaRoleType, OnErrorSkip
+from ..excepts import NoExplicitMessage, ExecutorFailToLoad, MemoryOverHighWatermark, DriverError
 from ..executors import BaseExecutor
 from ..logging import get_logger
 from ..logging.profile import used_memory, TimeDict
-from ..proto import jina_pb2, is_data_request
+from ..proto import jina_pb2
 
 __all__ = ['PeaMeta', 'BasePea']
 
@@ -128,17 +126,14 @@ class BasePea(metaclass=PeaMeta):
 
         self._request = None
         self._message = None
-        self._prev_requests = None
-        self._prev_messages = None
-        self._pending_msgs = defaultdict(list)  # type: Dict[str, List]
 
         if isinstance(args, argparse.Namespace):
             if args.name:
                 self.name = args.name
             if args.role == PeaRoleType.HEAD:
-                self.name = '%s-head' % self.name
+                self.name = f'{self.name}-head'
             elif args.role == PeaRoleType.TAIL:
-                self.name = '%s-tail' % self.name
+                self.name = f'{self.name}-tail'
             elif args.role == PeaRoleType.REPLICA:
                 self.name = '%s-%d' % (self.name, args.replica_id)
             self.ctrl_addr, self.ctrl_with_ipc = Zmqlet.get_ctrl_address(args)
@@ -149,34 +144,21 @@ class BasePea(metaclass=PeaMeta):
         else:
             self.logger = get_logger(self.name)
 
+    def __str__(self):
+        r = self.name
+        if self.executor is not None:
+            r += f'({str(self.executor)})'
+        return r
+
     def handle(self, msg: 'jina_pb2.Message') -> 'BasePea':
         """Register the current message to this pea, so that all message-related properties are up-to-date, including
         :attr:`request`, :attr:`prev_requests`, :attr:`message`, :attr:`prev_messages`. And then call the executor to handle
-        this message.
+        this message if its envelope's  status is not ERROR, else skip handling of message.
 
         :param msg: the message received
         """
-        self._request = getattr(msg.request, msg.request.WhichOneof('body'))
-        self._message = msg
-        req_type = type(self._request)
-
-        if self.args.num_part > 1 and is_data_request(self._request):
-            # do gathering, not for control request, unless it is dryrun
-            req_id = msg.envelope.request_id
-            self._pending_msgs[req_id].append(msg)
-            num_req = len(self._pending_msgs[req_id])
-
-            if num_req == self.args.num_part:
-                self._prev_messages = self._pending_msgs.pop(req_id)
-                self._prev_requests = [getattr(v.request, v.request.WhichOneof('body')) for v in self._prev_messages]
-            else:
-                raise NoExplicitMessage
-            self.logger.info(f'collected {num_req}/{self.args.num_part} parts of {req_type.__name__}')
-        else:
-            self._prev_requests = None
-            self._prev_messages = None
-
-        self.executor(self.request_type)
+        if msg.envelope.status.code != jina_pb2.Status.ERROR or self.args.skip_on_error < OnErrorSkip.HANDLE:
+            self.executor(self.request_type)
         return self
 
     @property
@@ -189,14 +171,6 @@ class BasePea(metaclass=PeaMeta):
         """Get the current request body inside the protobuf message"""
         return self._request
 
-    @property
-    def prev_requests(self) -> List['jina_pb2.Request']:
-        """Get all previous requests that has the same ``request_id``
-
-        This returns ``None`` when ``num_part=1``.
-        """
-        return self._prev_requests
-
     @property
     def message(self) -> 'jina_pb2.Message':
         """Get the current protobuf message to be processed"""
@@ -206,14 +180,6 @@ class BasePea(metaclass=PeaMeta):
     def request_type(self) -> str:
         return self._request.__class__.__name__
 
-    @property
-    def prev_messages(self) -> List['jina_pb2.Message']:
-        """Get all previous messages that has the same ``request_id``
-
-        This returns ``None`` when ``num_part=1``.
-        """
-        return self._prev_messages
-
     @property
     def log_iterator(self):
         """Get the last log using iterator """
@@ -267,13 +233,20 @@ class BasePea(metaclass=PeaMeta):
     def pre_hook(self, msg: 'jina_pb2.Message') -> 'BasePea':
         """Pre-hook function, what to do after first receiving the message """
         msg_type = msg.request.WhichOneof('body')
-        self.logger.info('received "%s" from %s' % (msg_type, routes2str(msg, flag_current=True)))
+        self.logger.info(f'received "{msg_type}" from {routes2str(msg, flag_current=True)}')
         add_route(msg.envelope, self.name, self.args.identity)
+        self._request = getattr(msg.request, msg_type)
+        self._message = msg
         return self
 
     def post_hook(self, msg: 'jina_pb2.Message') -> 'BasePea':
         """Post-hook function, what to do before handing out the message """
         msg.envelope.routes[-1].end_time.GetCurrentTime()
+        if self.args.num_part > 1:
+            msg.envelope.num_part.append(self.args.num_part)
+        self.last_active_time = time.perf_counter()
+        self.save_executor(self.args.dump_interval)
+        self.check_memory_watermark()
         return self
 
     def set_ready(self, *args, **kwargs):
@@ -287,9 +260,8 @@ class BasePea(metaclass=PeaMeta):
         self.logger.success(__stop_msg__)
 
     def _callback(self, msg):
-        # self.is_busy.set()
-        self.pre_hook(msg).handle(msg).post_hook(msg)
-        self.last_active_time = time.perf_counter()
+        if msg.envelope.status.code != jina_pb2.Status.ERROR or self.args.skip_on_error < OnErrorSkip.CALLBACK:
+            self.pre_hook(msg).handle(msg).post_hook(msg)
         return msg
 
     def msg_callback(self, msg: 'jina_pb2.Message') -> Optional['jina_pb2.Message']:
@@ -298,15 +270,40 @@ class BasePea(metaclass=PeaMeta):
         When nothing is returned then the nothing is send out via :attr:`zmqlet.sock_out`.
         """
         try:
+            # notice how executor related exceptions are handled here
+            # generally unless executor throws an OSError, the exception are caught and solved inplace
             return self._callback(msg)
+        except (SystemError, zmq.error.ZMQError, KeyboardInterrupt):
+            # serious error happen in callback, we need to break the event loop
+            raise
         except NoExplicitMessage:
-            # silent and do not propagade message anymore
+            # silent and do not propagate message anymore
             # 1. wait partial message to be finished
             # 2. dealer send a control message and no need to go on
             pass
+        except (RuntimeError, Exception) as ex:
+            # general runtime error and nothing serious, we simply mark the message to error and pass on
+            msg.envelope.status.code = jina_pb2.Status.ERROR
+            if not msg.envelope.status.description:
+                msg.envelope.status.description = f'{self} throws {repr(ex)}'
+            d = msg.envelope.status.details.add()
+            d.pod = self.name
+            d.pod_id = self.args.identity
+            d.exception = repr(ex)
+            d.executor = str(getattr(self, 'executor', ''))
+            d.traceback = traceback.format_exc()
+            d.time.GetCurrentTime()
+            self.logger.error(ex, exc_info=True)
+            return msg
 
     def loop_body(self):
-        """The body of the request loop """
+        """The body of the request loop
+
+        .. note::
+
+            Class inherited from :class:`BasePea` must override this function. And add
+            :meth:`set_ready` when your loop body is started
+        """
         self.load_plugins()
         self.load_executor()
         self.zmqlet = Zmqlet(self.args, logger=self.logger)
@@ -319,9 +316,6 @@ class BasePea(metaclass=PeaMeta):
 
             if msg:
                 self.zmqlet.send_message(msg)
-
-                self.save_executor(self.args.dump_interval)
-                self.check_memory_watermark()
                 # self.is_busy.clear()
             # t_loop_end = time.perf_counter()
             # self.logger.info(f'handle {(t_callback - t_loop_start) / (t_loop_end - t_loop_start):2.2f}')
@@ -350,26 +344,22 @@ class BasePea(metaclass=PeaMeta):
         try:
             self.post_init()
             self.loop_body()
-        except RequestLoopEnd:
-            self.logger.info('break from the event loop')
         except ExecutorFailToLoad:
-            self.logger.error('can not start a executor from %s' % self.args.yaml_path)
+            self.logger.critical(f'can not start a executor from {self.args.yaml_path}')
         except MemoryOverHighWatermark:
-            self.logger.error(
-                'memory usage %d GB is above the high-watermark: %d GB' % (used_memory(), self.args.memory_hwm))
-        except UnknownControlCommand as ex:
-            self.logger.error(ex, exc_info=True)
-        except DriverNotInstalled:
-            self.logger.error('no driver is installed to this pea, this pea will do nothing')
-        except NoDriverForRequest:
-            self.logger.error(f'no matched driver for {self.request_type} request, '
-                              f'this pea is either badly configured or it is not configured to handle {self.request_type} request')
+            self.logger.critical(
+                f'memory usage {used_memory()} GB is above the high-watermark: {self.args.memory_hwm} GB')
+        except DriverError as ex:
+            self.logger.critical(f'driver error: {repr(ex)}', exc_info=True)
         except KeyboardInterrupt:
-            self.logger.warning('user cancel the process')
+            self.logger.warning('break from the event loop or user cancel the process')
         except zmq.error.ZMQError:
-            self.logger.error('zmqlet can not be initiated')
+            self.logger.critical('zmqlet can not be initiated')
         except Exception as ex:
-            self.logger.error('unknown exception: %s' % str(ex), exc_info=True)
+            # this captures the general exception from the following places:
+            # - self.zmqlet.recv_message
+            # - self.zmqlet.send_message
+            self.logger.critical(f'unknown exception: {repr(ex)}', exc_info=True)
         finally:
             self.loop_teardown()
             self.unset_ready()
@@ -403,9 +393,15 @@ class BasePea(metaclass=PeaMeta):
     def start(self):
         super().start()
         if isinstance(self.args, dict):
-            _timeout = getattr(self.args['peas'][0], 'timeout_ready', 5e3) / 1e3
+            _timeout = getattr(self.args['peas'][0], 'timeout_ready', -1)
         else:
-            _timeout = getattr(self.args, 'timeout_ready', 5e3) / 1e3
+            _timeout = getattr(self.args, 'timeout_ready', -1)
+
+        if _timeout <= 0:
+            _timeout = None
+        else:
+            _timeout /= 1e3
+
         if self.ready_or_shutdown.wait(_timeout):
             if self.is_shutdown.is_set():
                 self.logger.critical(f'fail to start {self.__class__} with name {self.name}')
