@@ -15,7 +15,7 @@ import zmq.asyncio
 from .. import __default_host__
 from ..enums import SocketType
 from ..excepts import MismatchedVersion
-from ..helper import colored, get_random_identity, get_readable_size
+from ..helper import colored, get_random_identity, get_readable_size, use_uvloop
 from ..logging import default_logger, profile_logger
 from ..logging.base import get_logger
 from ..proto import jina_pb2, is_data_request
@@ -25,6 +25,8 @@ if False:
     import argparse
     import logging
 
+use_uvloop()
+
 
 class Zmqlet:
     """A `Zmqlet` object can send/receive data to/from ZeroMQ socket and invoke callback function. It
